@@ -17,6 +17,7 @@ use UNIVERSAL::require;
 
 use FusionInventory::Agent::XML::Query;
 use FusionInventory::Agent::Tools;
+use FusionInventory::Agent::Tools::Hardware;
 use FusionInventory::Agent::Tools::Network;
 use FusionInventory::Agent::Tools::SNMP;
 
@@ -36,7 +37,7 @@ my %properties = (
     CPU          => 'cpu',
     LOCATION     => 'location',
     FIRMWARE     => 'firmware',
-    CONTACT      => 'contant',
+    CONTACT      => 'contact',
     COMMENTS     => 'comments',
     UPTIME       => 'uptime',
     SERIAL       => 'serial',
@@ -430,11 +431,6 @@ sub _setGenericProperties {
     my $results = $params{results};
     my $device  = $params{device};
 
-    if ($results->{cpuuser}) {
-        $device->{INFO}->{CPU} =
-            $results->{cpuuser} + $results->{cpusystem};
-    }
-
     if ($results->{firmware1}) {
         $device->{INFO}->{FIRMWARE} = $results->{firmware1};
     }
@@ -480,8 +476,8 @@ sub _setGenericProperties {
     }
 
     if ($results->{ipAdEntAddr}) {
-        $device->{INFO}->{IPS}->{IP} = [
-            values %{$results->{ipAdEntAddr}}
+        $device->{INFO}->{IPS}->{IP} =  [
+            sort values %{$results->{ipAdEntAddr}}
         ];
     }
 
@@ -643,7 +639,7 @@ sub _setNetworkingProperties {
 
     $device->{INFO}->{MODEL} = $results->{entPhysicalModelName};
 
-    my $comments = $device->{INFO}->{COMMENTS};
+    my $comments = $device->{INFO}->{DESCRIPTION} || $device->{INFO}->{COMMENTS};
     my $ports    = $device->{PORTS}->{PORT};
 
     # Detect VLAN
@@ -664,9 +660,9 @@ sub _setNetworkingProperties {
     # everything else is vendor-specific, and requires device description
     return unless $comments;
 
-    _setTrunkPorts($comments, $results, $ports);
+    setTrunkPorts($comments, $results, $ports);
 
-    _setConnectedDevices($comments, $results, $ports, $walks);
+    setConnectedDevices($comments, $results, $ports, $walks);
 
     # check if vlan-specific queries are needed
     my $vlan_query =
@@ -707,141 +703,17 @@ sub _setNetworkingProperties {
                     $snmp->walk($variable->{OID});
             }
 
-            _setConnectedDevicesMacAddresses(
+            setConnectedDevicesMacAddresses(
                 $comments, $results, $ports, $walks, $vlan_id
             );
         }
     } else {
         # set connected devices mac addresses only once
-        _setConnectedDevicesMacAddresses($comments, $results, $ports, $walks);
+        setConnectedDevicesMacAddresses($comments, $results, $ports, $walks);
     }
 
     # hardware-specific hacks
-    _performSpecificCleanup($comments, $results, $ports);
-}
-
-sub _setTrunkPorts {
-    my ($description, $results, $ports) = @_;
-
-    my @dispatch_table = (
-        {
-            match  => qr/(Cisco|ProCurve)/,
-            module => 'FusionInventory::Agent::Manufacturer',
-        },
-        {
-            match  => qr/Nortel/,
-            module => 'FusionInventory::Agent::Manufacturer::Nortel',
-        },
-    );
-
-    foreach my $entry (@dispatch_table) {
-        next unless $description =~ $entry->{match};
-
-        runFunction(
-            module   => $entry->{module},
-            function => 'setTrunkPorts',
-            params   => { results => $results, ports => $ports },
-            load     => 1
-        );
-
-        last;
-    }
-
-}
-
-sub _setConnectedDevices {
-    my ($description, $results, $ports, $walks) = @_;
-
-    my @dispatch_table = (
-        {
-            match  => qr/(Cisco|ProCurve|Juniper)/,
-            module => 'FusionInventory::Agent::Manufacturer',
-        },
-        {
-            match  => qr/Nortel/,
-            module => 'FusionInventory::Agent::Manufacturer::Nortel',
-        },
-    );
-
-    foreach my $entry (@dispatch_table) {
-        next unless $description =~ $entry->{match};
-
-        runFunction(
-            module   => $entry->{module},
-            function => 'setConnectedDevices',
-            params   => {
-                results => $results, ports => $ports, walks => $walks
-            },
-            load     => 1
-        );
-
-        last;
-    }
-}
-
-sub _setConnectedDevicesMacAddresses {
-    my ($description, $results, $ports, $walks, $vlan_id) = @_;
-
-    my @dispatch_table = (
-        {
-            match    => qr/(3Com|ProCurve|Nortel|Allied Telesis|ExtremeXOS)/,
-            module   => 'FusionInventory::Agent::Manufacturer',
-        },
-        {
-            match    => qr/Cisco/,
-            module   => 'FusionInventory::Agent::Manufacturer::Cisco',
-        },
-        {
-            match    => qr/Juniper/,
-            module   => 'FusionInventory::Agent::Manufacturer::Juniper',
-        }
-    );
-
-    foreach my $entry (@dispatch_table) {
-        next unless $description =~ $entry->{match};
-
-        runFunction(
-            module   => $entry->{module},
-            function => 'setConnectedDevicesMacAddresses',
-            params   => {
-                results => $results,
-                ports   => $ports,
-                walks   => $walks,
-                vlan_id => $vlan_id
-            },
-            load     => 1
-        );
-
-        last;
-    }
-}
-
-sub _performSpecificCleanup {
-    my ($description, $results, $ports, $walks) = @_;
-
-    my @dispatch_table = (
-        {
-            match    => qr/3Com IntelliJack/,
-            module   => 'FusionInventory::Agent::Manufacturer::3Com',
-            function => 'RewritePortOf225'
-        },
-    );
-
-    foreach my $entry (@dispatch_table) {
-        next unless $description =~ $entry->{match};
-
-        runFunction(
-            module   => $entry->{module},
-            function => $entry->{function},
-            params   => {
-                results => $results,
-                ports   => $ports
-            },
-            load     => 1
-        );
-
-        last;
-    }
+    performSpecificCleanup($comments, $results, $ports);
 }
 
 sub _getPercentValue {
